@@ -2,7 +2,7 @@
 Copyright 2021 Objectiv B.V.
 """
 import json
-from typing import Optional, Dict, Union, TYPE_CHECKING, List, Tuple
+from typing import Optional, Any, Dict, Union, TYPE_CHECKING, List, Tuple
 
 from sqlalchemy.engine import Dialect
 
@@ -118,6 +118,11 @@ class SeriesJsonb(Series):
         1                                    None
         2    [{'l': ['m', 'n', 'o']}, {'p': 'q'}]
         Name: jsonb_column, dtype: object
+
+    **Database support and types**
+
+    * Postgres: utilizes the 'jsonb' database type.
+    * BigQuery: json support coming soon
     """
     dtype = 'jsonb'
     # todo can only assign a type to one series type, and object is quite generic
@@ -360,6 +365,14 @@ class SeriesJsonb(Series):
         """ INTERNAL: Only here to not trigger errors from describe """
         raise NotImplementedError()
 
+    def materialize(
+            self,
+            node_name='manual_materialize',
+            limit: Any = None,
+            distinct: bool = False,
+    ):
+        raise Exception(f'{self.__class__.__name__} cannot be materialized.')
+
 
 class SeriesJson(SeriesJsonb):
     """
@@ -369,6 +382,10 @@ class SeriesJson(SeriesJsonb):
     cast to the jsonb type. As a result all methods of the :py:class:`SeriesJsonb` can also be used with this
     `json` type series.
 
+    **Database support and types**
+
+    * Postgres: utilizes the 'json' database type.
+    * BigQuery: support coming soon
     """
     dtype = 'json'
     dtype_aliases: Tuple[DtypeOrAlias, ...] = tuple()
